==> Glossary-0.6.7.tar.gz: Glossary/lang/ext/fr_FR.php <==
<?php
$lang['areyousure_altercontent'] = '&Ecirc;tes-vous s&ucirc;r de vouloir effectuer cette op&eacute;ration ? Le fait de continuer modifiera le contenu';
$lang['filter_site_now'] = 'Filtrer';
$lang['friendlyname'] = 'Glossaire/Dictionnaire/FAQ';
$lang['postinstall'] = '<p>Assurez-vous d&#039;avoir d&eacute;fini les permissions &quot;Modify Glossary&quot; pour utiliser ce module !</p>
<p>You&#039;ll almost certainly want to go in and change settings as well. I intentionally chose odd settings
in order to demonstrate features. But you will probably want more than five terms on a page, for example,
and you will want to delete my sample terms and categories.';
$lang['postuninstall'] = 'Suppression r&eacute;alis&eacute;e avec succ&egrave;s.';
$lang['uninstalled'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module est install&eacute;e.';
$lang['prefsupdated'] = 'Pr&eacute;f&eacute;rences mise &agrave; jour avec succ&egrave;s.';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. V&eacute;rifier vos permissions.';
$lang['error'] = 'Erreur !';
$lang['upgraded'] = 'Le module a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s.';
$lang['title_mod_prefs'] = 'Pr&eacute;f&eacute;rences du Module ';
$lang['title_mod_admin'] = 'Panneau d&#039;administration du Module';
$lang['title_term'] = 'Termes';
$lang['title_definition'] = 'D&eacute;finition';
$lang['column_definition'] = 'D&eacute;finition';
$lang['title_default_template'] = 'Gabarit d&#039;affichage par d&eacute;faut';
$lang['title_default_single_term_template'] = 'Gabarit par d&eacute;faut des termes (si affichage simple des termes)';
$lang['title_filter_site'] = 'Trier automatiquement des pages contenant les termes ?';
$lang['title_filter_news'] = 'Trier les nouveaux articles pour les termes ?';
$lang['title_number_show'] = 'Nombre de termes par page';
$lang['title_default_number_show'] = 'Nombre de termes par page par d&eacute;faut';
$lang['title_filter_site_label'] = 'Activer tous les termes ? (Attention - ralentit les performances du site)';
$lang['title_glossary_page'] = 'Page par d&eacute;faut qui contient le glossaire (cible des liens actifs)';
$lang['title_disable_prettyurls'] = 'D&eacute;sactiver l&#039;utilisation des URL propres (pretty URLs) pour ce module';
$lang['title_disable_prettyurls_label'] = 'D&eacute;sactiver';
$lang['title_glossary_inline'] = 'Utilisation des liens inline ?';
$lang['title_show_termids'] = 'Afficher les IDs des termes';
$lang['title_display_tab'] = 'Options d&#039;affichage';
$lang['title_single_term'] = 'Afficher le lien dans la m&ecirc;me page ?';
$lang['title_single_term_label'] = 'Affichage simple des termes';
$lang['title_wysiwyg_definitions'] = 'Utiliser le WYSIWYG pour entrer les d&eacute;finitions de termes ?';
$lang['title_wysiwyg_terms'] = 'Utiliser le WYSIWYG pour entrer les termes ?';
$lang['title_wysiwyg_terms_help'] = 'Veuillez noter que le balisage dans les termes peuvent interf&eacute;rer avec le tri alphab&eacute;tique et avec les termes activ&eacute;s!';
$lang['title_link_tab'] = 'Options des liens';
$lang['title_admin_tab'] = 'Options d&#039;administration';
$lang['title_filtering_tab'] = 'Options de tri des termes';
$lang['title_number_spining_chars'] = 'Nombre maximum de caract&egrave;res d&#039;un terme pour la navigation';
$lang['title_process_smarty'] = 'Utiliser les balises Smarty dans D&eacute;finitions ?';
$lang['filter_link'] = 'Lien vers la page glossaire';
$lang['column_term'] = 'Terme';
$lang['column_termid'] = 'IDs';
$lang['column_action'] = 'Action ';
$lang['column_category'] = 'Cat&eacute;gorie';
$lang['title_admin_panel'] = 'Glossaire/Dictionnaire/FAQ';
$lang['title_term_list'] = 'Termes';
$lang['title_name'] = 'Nom';
$lang['title_cats'] = 'Cat&eacute;gories';
$lang['title_filter_category'] = 'Affichez seulement cette cat&eacute;gorie :';
$lang['title_all'] = 'Toutes les cat&eacute;gories';
$lang['column_template'] = 'Nom du gabarit';
$lang['title_template'] = 'D&eacute;finition du gabarit';
$lang['addterm'] = 'Ajouter un terme';
$lang['termadded'] = 'Terme ajout&eacute;.';
$lang['termdeleted'] = 'Terme effac&eacute;.';
$lang['edit'] = 'Modifier le terme';
$lang['no'] = 'Non';
$lang['yes'] = 'Oui';
$lang['filter'] = 'Trier';
$lang['delete'] = 'Effacer le terme';
$lang['suredelete'] = '&Ecirc;tes-vous s&ucirc;r de vouloir effacer le terme %s?';
$lang['listterms'] = 'Termes';
$lang['listtempl'] = 'Gabarits';
$lang['listcats'] = 'Cat&eacute;gories';
$lang['addcat'] = 'Ajouter une cat&eacute;gorie';
$lang['editcat'] = 'Modifier une cat&eacute;gorie';
$lang['delcat'] = 'Supprimer une cat&eacute;gorie';
$lang['manageprefs'] = 'Options';
$lang['templatelist'] = 'Gabarits';
$lang['unknown_term'] = 'Terme inconnu %s.';
$lang['glossary_page_help'] = 'Choisissez la page par d&eacute;faut qui contient le glossaire. Cette page doit contenir la balise smarty qui appelle le glossaire {cms_module module=&quot;Glossary&quot;}';
$lang['glossary_prettyurls_help'] = 'D&eacute;sactiver l&#039;utilisation des URL propres (pretty URLs) pour ce module peut &ecirc;tre n&eacute;cessaire si vos termes contiennent des caract&egrave;res alphanum&eacute;riques ou des espaces.';
$lang['glossary_inline_help'] = 'Utilisez l&#039;option suivante pour avoir l&#039;affichage des d&eacute;finitions en mode inline. Fonctionne en liaison avec la page appelant le glossaire.';
$lang['title_glossary_inline_label'] = 'Afficher Inline';
$lang['notemplates'] = 'Aucun gabarit dans la base de donn&eacute;es.';
$lang['nocats'] = 'Aucune cat&eacute;gorie dans la base de donn&eacute;es.';
$lang['addtemplate'] = 'Ajouter un gabarit';
$lang['templateupdated'] = 'Gabarit mis &agrave; jour';
$lang['templatedeleted'] = 'Gabarit effac&eacute;';
$lang['catupdated'] = 'Cat&eacute;gorie mise &agrave; jour';
$lang['catdeleted'] = 'Cat&eacute;gorie effac&eacute;e';
$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r de vouloir effacer %s?';
$lang['next'] = ' : Suivant &raquo;';
$lang['prev'] = '&laquo; Pr&eacute;c&eacute;dent : ';
$lang['moddescription'] = 'Cette liste peut &ecirc;tre un glossaire, un dictionnaire, une FAQ ou quelque chose de similaire.';
$lang['changelog'] = '<ul>
<li>Version 0.6.6,  January 2009. Bug fixes, added &quot;random&quot; action, option to allow smarty tags in definitions</li>
<li>Version 0.6.5,  January 2009. Bug fixes, now allows teplate specification to be name or id.</li>
<li>Version 0.6.4,  September 2008.  Adds glossary terms to the searchable content.  Bump minimum cms version to 1.4.1</li>
<li>Version 0.6.3,  March 2008.  Adds the ability to disable pretty urls for this module.  Bump minimum cms version to 1.2</li>
<li>Version 0.6.2.  December 2007.  Fixes a bug in preferences related to inline/non inline, bumps minimum cms version, Adds the RegisterModulePlugin call.</li>
<li>Version 0.6.1.  November 2007.  Adds functionality so that content never returns empty</li>
<li>Version 0.6. November 2007.  Adds a button to filter content and news on demand, splits it out into multiple files for reduced memory footprint.</li>
<li>Version 0.5.1. 28 Mar 2007.  Urls now validate. There ya go, Mr. InSiPiD.</li>
<li>Version 0.5. 8 November 2006. Removed pop-up window links, added inline display, and category filtering / requested features for InSiPiD.</li>
<li>Version 0.4. 7 November 2006. Updated for CMS MS 1.0.x, added features for InSiPiD.</li>
<li>Version 0.3. 24 October 2005. Bug fixes, new default template, more Admin configuration options.</li>
<li>Version 0.2. 20 October 2005. Initial Public Release.</li></ul>';
$lang['help_glossary_single'] = 'Afficher un terme unique';
$lang['help_glossary_tid'] = 'Id du terme en surlign&eacute;/soulign&eacute;';
$lang['help_glossary_catid'] = 'R&eacute;duire la liste aux termes de la cat&eacute;gorie &agrave; l&#039;ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Offset in list to start listing terms';
$lang['help_glossary_term'] = 'terme en surlign&eacute;/soulign&eacute;';
$lang['help_glossary_cat'] = 'R&eacute;duire la liste aux termes de la cat&eacute;gorie &quot;cat&quot;';
$lang['help_glossary_template'] = 'Nom du gabarit ou ID &agrave; utiliser pour formater les termes';
$lang['help_glossary_term_count'] = 'Nombre de terms &agrave; afficher par page (&eacute;crase les param&egrave;tres par d&eacute;faut de l&#039;administration)';
$lang['help_glossary_show_nav'] = 'D&eacute;finir &agrave; 0 pour cacher la navigation par pagination';
$lang['help_glossary_keyword'] = 'Restrict to terms whose definitions contain &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sort order: currently only supports &quot;alpha&quot; or &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'Pour afficher une liste filtr&eacute;e ou une autre liste restreinte, mais garder la liste enti&egrave;re non restrainte, listez les champs ici (voir l&#039;exemple ci-dessus)';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>Ce module est utilis&eacute; pour g&eacute;rer une liste de termes (glossaire/dictionnaire/FAQ). Un clic sur un terme permet d&#039;acc&eacute;der directement &agrave; sa d&eacute;finition.</p>
<h3>Comment l&#039;utiliser ?</h3>
<h4>Page standard</h4>
<p>Pour afficher un glossaire, utilisez simplement la balise smarty suivante dans votre contenu : {cms_module module=&#039;Glossary&#039;}</p>
<p>Vous pouvez d&eacute;marrer avec l&#039;affichage d&#039;une d&eacute;finition en utilisant le param&egrave;tre : term=Term ou en utilisant son ID: tid=term_id.</p>
<p>Vous pouvez aussi limiter l&#039;affichage &agrave; une cat&eacute;gorie en utilisant le param&egrave;tre : cat=&quot;Category&quot;.</p>
<p>Vous pouvez outre passer le gabarit par d&eacute;faut en utilisant un param&egrave;tre : template=&quot;template_id&quot;.</p>
<p>Ce module est capable de lire une URL et d&#039;interpr&eacute;ter l&#039;emploi des param&egrave;tres &quot;term&quot; ou &quot;cat&quot;. Par exemple, vous pouvez avoir une URL du type : http://mysite/index.php?page=10?term=myterm. Si la page 10 incl&ucirc;t le glossaire, alors le module affichera la d&eacute;finition de &quot;myterm&quot; 
<h3>Liens</h3>
<h4>G&eacute;n&eacute;ralit&eacute;s</h4>
<p>Vous pouvez faire ressortir les liens de vos termes, soit en utilisant le mode &quot;inline&quot; soit en les liant &agrave; la page contenant le glossaire. C&#039;est l&#039;option &quot;inline&quot; que vous pouvez d&eacute;finir dans l&#039;onglet &quot;Options des liens&quot; dans la section &quot;Options&quot; du module.</p>
<p>Vous pouvez &eacute;galement choisir d&#039;avoir vos liens qui s&#039;affichent sur une page avec la d&eacute;finition seule de votre terme. Il vous faut pour cela modifier les gabarits. Cette option se d&eacute;finit dans l&#039;onglet &quot;Options des liens&quot; dans la section &quot;Options&quot; du module. </p> 
<h4>Single Term</h4>
<p>Vous pouvez marquer/&eacute;tiqueter des mots en les reliant au glossaire en utilisant la balise smarty suivante dans votre page: {cms_module module=&#039;Glossary&#039; action=&#039;def&#039; term=&#039;foo&#039;}, o&ugrave; &quot;foo&quot; sera remplac&eacute; par un terme de votre glossaire.
<h4>Term Replacement / Site Filtering</h4>
<p>If you turn on site filtering, every instance of each of your terms that shows up on the site will become a link. Depending on the mode you choose in the admin,
this will either be a link to your main Glossary page or open to the term in question.</p>
<p>Site filtering is an intensive process, and will slow your site down somewhat. There is an alternate, faster implementation that I may use to replace the existing one,
if there are enough complaints. It&#039;s more complicated, and I&#039;m lazy, but given sufficient demand, I&#039;ll fix it.</p>
<h3>Support</h3>
<p>Ce module n&#039;inclut pas de support commercial mais un certain nombre de ressources sont disponibles :</p>
<ul>
<li>Pour la derni&egrave;re version, les questions fr&eacute;quentes et la r&eacute;solution de probl&egrave;mes, rendez vous sur<a href="http://dev.cmsmadesimple.org/projects/glossary/">la forge the CMS</a>.</li>
<li>Plus de discussions sur ce module sur le forum : <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>Vous pouvez trouvez l&#039;auteur , SjG, <a href="irc://irc.freenode.net/#cms">sur le canal IRC de CMS Made Simple</a>.</li>
<li>Pour finir vous pouvez envoyer un courrier &eacute;lectronique directement &agrave; l&#039;auteur.</li>
</ul>
<p>Conform&eacute;ment &agrave; la licence GPL, ce module est distribu&eacute; tel quel. Veuillez vous r&eacute;f&eacute;rer directement &agrave; la licence pour tout avis de non responsabilit&eacute;.</p>

<h3>Copyright et License</h3>
<p>Copyright &copy; 2006, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com"><sjg@cmsmodules.com></a>. Tous droits r&eacute;serv&eacute;s.</p>
<p>Ce module est distribu&eacute; sous la licence  <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>
';
$lang['utma'] = '156861353.23806501199468600.1229087340.1236859462.1236869527.50';
$lang['utmz'] = '156861353.1236167241.41.27.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1236869527';
?>

==> Glossary-1.0.tar.gz: Glossary/lang/ext/fr_FR.php <==
<?php
$lang['areyousure_altercontent'] = '&Ecirc;tes-vous s&ucirc;r de vouloir effectuer cette op&eacute;ration ? Le fait de continuer modifiera le contenu';
$lang['filter_site_now'] = 'Filtrer';
$lang['friendlyname'] = 'Glossaire/Dictionnaire/FAQ';
$lang['postinstall'] = '<p>Assurez-vous d&#039;avoir d&eacute;fini les permissions &quot;Modify Glossary&quot; pour utiliser ce module !</p>
<p>You&#039;ll almost certainly want to go in and change settings as well. I intentionally chose odd settings
in order to demonstrate features. But you will probably want more than five terms on a page, for example,
and you will want to delete my sample terms and categories.';
$lang['postuninstall'] = 'Suppression r&eacute;alis&eacute;e avec succ&egrave;s.';
$lang['uninstalled'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module est install&eacute;e.';
$lang['prefsupdated'] = 'Pr&eacute;f&eacute;rences mise &agrave; jour avec succ&egrave;s.';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. V&eacute;rifier vos permissions.';
$lang['error'] = 'Erreur !';
$lang['upgraded'] = 'Le module a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s.';
$lang['title_mod_prefs'] = 'Pr&eacute;f&eacute;rences du Module ';
$lang['title_mod_admin'] = 'Panneau d&#039;administration du Module';
$lang['title_term'] = 'Termes';
$lang['title_definition'] = 'D&eacute;finition';
$lang['column_definition'] = 'D&eacute;finition';
$lang['title_default_template'] = 'Gabarit d&#039;affichage par d&eacute;faut';
$lang['title_default_single_term_template'] = 'Gabarit par d&eacute;faut des termes (si affichage simple des termes)';
$lang['title_filter_site'] = 'Trier automatiquement des pages contenant les termes ?';
$lang['title_filter_news'] = 'Trier les nouveaux articles pour les termes ?';
$lang['title_number_show'] = 'Nombre de termes par page';
$lang['title_default_number_show'] = 'Nombre de termes par page par d&eacute;faut';
$lang['title_filter_site_label'] = 'Activer tous les termes ? (Attention - ralentit les performances du site)';
$lang['title_glossary_page'] = 'Page par d&eacute;faut qui contient le glossaire (cible des liens actifs)';
$lang['title_disable_prettyurls'] = 'D&eacute;sactiver l&#039;utilisation des URL propres (pretty URLs) pour ce module';
$lang['title_disable_prettyurls_label'] = 'D&eacute;sactiver';
$lang['title_glossary_inline'] = 'Utilisation des liens inline ?';
$lang['title_show_termids'] = 'Afficher les IDs des termes';
$lang['title_display_tab'] = 'Options d&#039;affichage';
$lang['title_single_term'] = 'Afficher le lien dans la m&ecirc;me page ?';
$lang['title_single_term_label'] = 'Affichage simple des termes';
$lang['title_wysiwyg_definitions'] = 'Utiliser le WYSIWYG pour entrer les d&eacute;finitions de termes ?';
$lang['title_wysiwyg_terms'] = 'Utiliser le WYSIWYG pour entrer les termes ?';
$lang['title_wysiwyg_terms_help'] = 'Veuillez noter que le balisage dans les termes peuvent interf&eacute;rer avec le tri alphab&eacute;tique et avec les termes activ&eacute;s!';
$lang['title_link_tab'] = 'Options des liens';
$lang['title_admin_tab'] = 'Options d&#039;administration';
$lang['title_filtering_tab'] = 'Options de tri des termes';
$lang['title_number_spining_chars'] = 'Nombre maximum de caract&egrave;res d&#039;un terme pour la navigation';
$lang['title_process_smarty'] = 'Utiliser les balises Smarty dans D&eacute;finitions ?';
$lang['filter_link'] = 'Lien vers la page glossaire';
$lang['column_term'] = 'Terme';
$lang['column_termid'] = 'IDs';
$lang['column_action'] = 'Action ';
$lang['column_category'] = 'Cat&eacute;gorie';
$lang['title_admin_panel'] = 'Glossaire/Dictionnaire/FAQ';
$lang['title_term_list'] = 'Termes';
$lang['title_name'] = 'Nom';
$lang['title_cats'] = 'Cat&eacute;gories';
$lang['title_filter_category'] = 'Affichez seulement cette cat&eacute;gorie :';
$lang['title_all'] = 'Toutes les cat&eacute;gories';
$lang['column_template'] = 'Nom du gabarit';
$lang['title_template'] = 'D&eacute;finition du gabarit';
$lang['addterm'] = 'Ajouter un terme';
$lang['termadded'] = 'Terme ajout&eacute;.';
$lang['termdeleted'] = 'Terme effac&eacute;.';
$lang['edit'] = 'Modifier le terme';
$lang['no'] = 'Non';
$lang['yes'] = 'Oui';
$lang['filter'] = 'Trier';
$lang['delete'] = 'Effacer le terme';
$lang['suredelete'] = '&Ecirc;tes-vous s&ucirc;r de vouloir effacer le terme %s?';
$lang['listterms'] = 'Termes';
$lang['listtempl'] = 'Gabarits';
$lang['listcats'] = 'Cat&eacute;gories';
$lang['addcat'] = 'Ajouter une cat&eacute;gorie';
$lang['editcat'] = 'Modifier une cat&eacute;gorie';
$lang['delcat'] = 'Supprimer une cat&eacute;gorie';
$lang['manageprefs'] = 'Options';
$lang['templatelist'] = 'Gabarits';
$lang['unknown_term'] = 'Terme inconnu %s.';
$lang['glossary_page_help'] = 'Choisissez la page par d&eacute;faut qui contient le glossaire. Cette page doit contenir la balise smarty qui appelle le glossaire {cms_module module=&quot;Glossary&quot;}';
$lang['glossary_prettyurls_help'] = 'D&eacute;sactiver l&#039;utilisation des URL propres (pretty URLs) pour ce module peut &ecirc;tre n&eacute;cessaire si vos termes contiennent des caract&egrave;res alphanum&eacute;riques ou des espaces.';
$lang['glossary_inline_help'] = 'Utilisez l&#039;option suivante pour avoir l&#039;affichage des d&eacute;finitions en mode inline. Fonctionne en liaison avec la page appelant le glossaire.';
$lang['title_glossary_inline_label'] = 'Afficher Inline';
$lang['notemplates'] = 'Aucun gabarit dans la base de donn&eacute;es.';
$lang['nocats'] = 'Aucune cat&eacute;gorie dans la base de donn&eacute;es.';
$lang['addtemplate'] = 'Ajouter un gabarit';
$lang['templateupdated'] = 'Gabarit mis &agrave; jour';
$lang['templatedeleted'] = 'Gabarit effac&eacute;';
$lang['catupdated'] = 'Cat&eacute;gorie mise &agrave; jour';
$lang['catdeleted'] = 'Cat&eacute;gorie effac&eacute;e';
$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r de vouloir effacer %s?';
$lang['next'] = ' : Suivant &raquo;';
$lang['prev'] = '&laquo; Pr&eacute;c&eacute;dent : ';
$lang['moddescription'] = 'Cette liste peut &ecirc;tre un glossaire, un dictionnaire, une FAQ ou quelque chose de similaire.';
$lang['help_glossary_single'] = 'Afficher un terme unique';
$lang['help_glossary_tid'] = 'Id du terme en surlign&eacute;/soulign&eacute;';
$lang['help_glossary_catid'] = 'R&eacute;duire la liste aux termes de la cat&eacute;gorie &agrave; l&#039;ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Position de la liste pour d&eacute;marer le listing des &eacute;lements.';
$lang['help_glossary_term'] = 'terme en surlign&eacute;/soulign&eacute;';
$lang['help_glossary_cat'] = 'R&eacute;duire la liste aux termes de la cat&eacute;gorie &quot;cat&quot;';
$lang['help_glossary_template'] = 'Nom du gabarit ou ID &agrave; utiliser pour formater les termes';
$lang['help_glossary_term_count'] = 'Nombre de terms &agrave; afficher par page (&eacute;crase les param&egrave;tres par d&eacute;faut de l&#039;administration)';
$lang['help_glossary_show_nav'] = 'D&eacute;finir &agrave; 0 pour cacher la navigation par pagination';
$lang['help_glossary_keyword'] = 'Restrict to terms whose definitions contain &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sort order: currently only supports &quot;alpha&quot; or &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'Pour afficher une liste filtr&eacute;e ou une autre liste restreinte, mais garder la liste enti&egrave;re non restrainte, listez les champs ici (voir l&#039;exemple ci-dessus)';
?>
